@@ -4,9 +4,9 @@
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#include <QtQuickTest>
-#include <QQmlEngine>
 #include <QQmlContext>
+#include <QQmlEngine>
+#include <QtQuickTest/quicktest.h>
 
 #include <KLocalizedContext>
 #include <KLocalizedString>
@@ -30,7 +30,7 @@ public Q_SLOTS:
 
         qmlRegisterType<ExampleAlbumModel>("test.artefacts", 1, 0, "ExampleAlbumModel");
 
-        engine->rootContext()->setContextProperty(QLatin1String("dataDir"), QVariant(QLatin1String(DATA_DIR)));
+        engine->rootContext()->setContextProperty(QStringLiteral("dataDir"), QVariant(QLatin1String(DATA_DIR)));
     }
 };
 
